/// <reference types="react" />
import * as yup_lib_object from 'yup/lib/object';
import * as yup_lib_string from 'yup/lib/string';
import { CognitoUserSession } from 'amazon-cognito-identity-js';
import * as Yup from 'yup';
import React$1 from 'react';

declare const formDefaults$4: yup_lib_object.TypeOfShape<{
    code: yup_lib_string.RequiredStringSchema<string, Record<string, any>>;
}>;
declare type ConfirmAccountValues = typeof formDefaults$4;
interface ConfirmAccountFormProps {
    email: string;
    onSubmit: (values: ConfirmAccountValues) => Promise<void>;
    onResendCode: () => Promise<void>;
}
declare function ConfirmAccountForm({ email, onSubmit, onResendCode, }: ConfirmAccountFormProps): JSX.Element;

interface IProfile {
    email: string;
    firstName: string;
    lastName: string;
    allowMarketing: boolean;
}
interface IAuthContext {
    session: CognitoUserSession;
    profile: IProfile;
    updateSession: () => Promise<void>;
    signOut: () => void;
}

declare enum AuthMode {
    SIGN_UP = "SIGN_UP",
    CONFIRM_ACCOUNT = "CONFIRM_ACCOUNT",
    SIGN_IN = "SIGN_IN",
    FORGOT_PASSWORD = "FORGOT_PASSWORD",
    RESET_PASSWORD = "RESET_PASSWORD",
    SIGN_OUT = "SIGN_OUT"
}
interface IUpdateSession {
    type: 'UPDATE_SESSION';
    payload: {
        session: CognitoUserSession | null;
    };
}
interface ISwitchMode {
    type: 'SWITCH_MODE';
    payload: {
        authMode: AuthMode;
        email?: string;
    };
}
declare type IAuthAction = IUpdateSession | ISwitchMode;

declare const formDefaults$3: yup_lib_object.TypeOfShape<{
    email: yup_lib_string.RequiredStringSchema<string, Record<string, any>>;
}>;
declare type ForgotPasswordValues = typeof formDefaults$3;
interface ForgotPasswordFormProps {
    email: string;
    onSubmit: (values: ForgotPasswordValues) => Promise<void>;
    dispatch: React.Dispatch<IAuthAction>;
}
declare function ForgotPasswordForm({ email, onSubmit, dispatch, }: ForgotPasswordFormProps): JSX.Element;

declare const formDefaults$2: yup_lib_object.TypeOfShape<{
    code: yup_lib_string.RequiredStringSchema<string, Record<string, any>>;
    password: yup_lib_string.RequiredStringSchema<string, Record<string, any>>;
    passwordConfirm: yup_lib_string.RequiredStringSchema<string, Record<string, any>>;
}>;
declare type ResetPasswordValues = typeof formDefaults$2;
interface ResetPasswordFormProps {
    email: string;
    onSubmit: (values: ResetPasswordValues) => Promise<void>;
}
declare function ResetPasswordForm({ email, onSubmit, }: ResetPasswordFormProps): JSX.Element;

declare const formDefaults$1: yup_lib_object.TypeOfShape<{
    email: yup_lib_string.RequiredStringSchema<string, Record<string, any>>;
    password: yup_lib_string.RequiredStringSchema<string, Record<string, any>>;
}>;
declare type SignInValues = typeof formDefaults$1;
interface SignInFormProps {
    email: string;
    onSubmit: (values: SignInValues) => Promise<void>;
    dispatch: React.Dispatch<IAuthAction>;
}
declare function SignInForm({ email, onSubmit, dispatch, }: SignInFormProps): JSX.Element;

interface SignOutProps {
    onSignOut: () => Promise<void>;
}
declare function SignOut({ onSignOut }: SignOutProps): JSX.Element;

declare const formDefaults: yup_lib_object.TypeOfShape<{
    firstName: Yup.StringSchema<string, Record<string, any>, string>;
    lastName: Yup.StringSchema<string, Record<string, any>, string>;
    email: yup_lib_string.RequiredStringSchema<string, Record<string, any>>;
    password: yup_lib_string.RequiredStringSchema<string, Record<string, any>>;
    passwordConfirm: yup_lib_string.RequiredStringSchema<string, Record<string, any>>;
    allowMarketing: Yup.BooleanSchema<boolean, Record<string, any>, boolean>;
}>;
declare type SignUpValues = typeof formDefaults;
interface SignUpFormProps {
    email: string;
    onSubmit: (values: SignUpValues) => Promise<void>;
    dispatch: React$1.Dispatch<IAuthAction>;
}
declare function SignUpForm({ email, onSubmit, dispatch, }: SignUpFormProps): JSX.Element;

declare const AuthContext: React$1.Context<IAuthContext>;
interface AuthContextProviderProps {
    children: React$1.ReactNode;
    sessionPingDelay?: number;
}
declare function AuthContextProvider({ children, sessionPingDelay, }: AuthContextProviderProps): JSX.Element;

export { AuthContext, AuthContextProvider, AuthContextProviderProps, ConfirmAccountForm, ConfirmAccountFormProps, ConfirmAccountValues, ForgotPasswordForm, ForgotPasswordFormProps, ForgotPasswordValues, IAuthContext, IProfile, ResetPasswordForm, ResetPasswordFormProps, ResetPasswordValues, SignInForm, SignInFormProps, SignInValues, SignOut, SignOutProps, SignUpForm, SignUpFormProps, SignUpValues };
